{
    "$graph": [
        {
            "class": "CommandLineTool",
            "doc": "string",
            "requirements": [
                {
                    "dockerPull": "quay.io/biocontainers/bwa:0.7.17--h84994c4_5",
                    "class": "DockerRequirement"
                },
                {
                    "listing": [
                        "$(inputs.input_fasta)"
                    ],
                    "class": "InitialWorkDirRequirement"
                }
            ],
            "baseCommand": [
                "bwa",
                "index"
            ],
            "inputs": [
                {
                    "type": "File",
                    "label": "input fasta file",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#bwa-index.cwl/input_fasta"
                }
            ],
            "stdout": "bwa-index-stdout.log",
            "stderr": "bwa-index-stderr.log",
            "id": "#bwa-index.cwl",
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.input_fasta.basename).amb"
                    },
                    "id": "#bwa-index.cwl/amb"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.input_fasta.basename).ann"
                    },
                    "id": "#bwa-index.cwl/ann"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.input_fasta.basename).bwt"
                    },
                    "id": "#bwa-index.cwl/bwt"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.input_fasta.basename).pac"
                    },
                    "id": "#bwa-index.cwl/pac"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.input_fasta.basename).sa"
                    },
                    "id": "#bwa-index.cwl/sa"
                },
                {
                    "type": "File",
                    "id": "#bwa-index.cwl/stderr",
                    "outputBinding": {
                        "glob": "bwa-index-stderr.log"
                    }
                },
                {
                    "type": "File",
                    "id": "#bwa-index.cwl/stdout",
                    "outputBinding": {
                        "glob": "bwa-index-stdout.log"
                    }
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "doc": "string",
            "requirements": [
                {
                    "dockerPull": "quay.io/biocontainers/bwa:0.7.17--h84994c4_5",
                    "class": "DockerRequirement"
                },
                {
                    "listing": [
                        "$(inputs.index_base)",
                        "$(inputs.amb)",
                        "$(inputs.ann)",
                        "$(inputs.bwt)",
                        "$(inputs.pac)",
                        "$(inputs.sa)"
                    ],
                    "class": "InitialWorkDirRequirement"
                }
            ],
            "baseCommand": [
                "bwa",
                "mem"
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#bwa-mem.cwl/amb"
                },
                {
                    "type": "File",
                    "id": "#bwa-mem.cwl/ann"
                },
                {
                    "type": "File",
                    "id": "#bwa-mem.cwl/bwt"
                },
                {
                    "type": "File",
                    "label": "input fastq file to map (single-end or forward for pair-end)",
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#bwa-mem.cwl/fastq_forward"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "label": "input fastq file to map (reverse for pair-end)",
                    "inputBinding": {
                        "position": 3
                    },
                    "id": "#bwa-mem.cwl/fastq_reverse"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "label": "read group header line such as '@RG\tID:foo\tSM:bar'",
                    "inputBinding": {
                        "prefix": "-R"
                    },
                    "id": "#bwa-mem.cwl/group_header_line"
                },
                {
                    "type": "File",
                    "label": "fasta file for index basename",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#bwa-mem.cwl/index_base"
                },
                {
                    "type": "string",
                    "label": "sam file to output results to",
                    "default": "out.sam",
                    "inputBinding": {
                        "prefix": "-o"
                    },
                    "id": "#bwa-mem.cwl/output_sam"
                },
                {
                    "type": "File",
                    "id": "#bwa-mem.cwl/pac"
                },
                {
                    "type": "File",
                    "id": "#bwa-mem.cwl/sa"
                },
                {
                    "type": "int",
                    "label": "number of threads",
                    "default": 4,
                    "inputBinding": {
                        "prefix": "-t"
                    },
                    "id": "#bwa-mem.cwl/threads"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output_sam)"
                    },
                    "id": "#bwa-mem.cwl/output"
                },
                {
                    "type": "File",
                    "id": "#bwa-mem.cwl/stderr",
                    "outputBinding": {
                        "glob": "bwa-mem-stderr.log"
                    }
                },
                {
                    "type": "File",
                    "id": "#bwa-mem.cwl/stdout",
                    "outputBinding": {
                        "glob": "bwa-mem-stdout.log"
                    }
                }
            ],
            "stdout": "bwa-mem-stdout.log",
            "stderr": "bwa-mem-stderr.log",
            "id": "#bwa-mem.cwl"
        },
        {
            "class": "Workflow",
            "doc": "Sub workflow used in the Animal Genome Assembly pipeline by Kazuharu Arakawa (@gaou_ak), CWLized by Tazro Ohta (@inutano)",
            "requirements": [],
            "inputs": [
                {
                    "type": "File",
                    "id": "#main/INPUT_FASTA"
                },
                {
                    "type": "File",
                    "id": "#main/INPUT_SHORTREAD"
                },
                {
                    "type": "int",
                    "id": "#main/THREADS"
                }
            ],
            "steps": [
                {
                    "run": "#bwa-index.cwl",
                    "in": [
                        {
                            "source": "#main/INPUT_FASTA",
                            "id": "#main/bwa-index/input_fasta"
                        }
                    ],
                    "out": [
                        "#main/bwa-index/amb",
                        "#main/bwa-index/ann",
                        "#main/bwa-index/bwt",
                        "#main/bwa-index/pac",
                        "#main/bwa-index/sa"
                    ],
                    "id": "#main/bwa-index"
                },
                {
                    "run": "#bwa-mem.cwl",
                    "in": [
                        {
                            "source": "#main/bwa-index/amb",
                            "id": "#main/bwa-mem/amb"
                        },
                        {
                            "source": "#main/bwa-index/ann",
                            "id": "#main/bwa-mem/ann"
                        },
                        {
                            "source": "#main/bwa-index/bwt",
                            "id": "#main/bwa-mem/bwt"
                        },
                        {
                            "source": "#main/INPUT_SHORTREAD",
                            "id": "#main/bwa-mem/fastq_forward"
                        },
                        {
                            "source": "#main/INPUT_FASTA",
                            "id": "#main/bwa-mem/index_base"
                        },
                        {
                            "source": "#main/bwa-index/pac",
                            "id": "#main/bwa-mem/pac"
                        },
                        {
                            "source": "#main/bwa-index/sa",
                            "id": "#main/bwa-mem/sa"
                        },
                        {
                            "source": "#main/THREADS",
                            "id": "#main/bwa-mem/threads"
                        }
                    ],
                    "out": [
                        "#main/bwa-mem/output"
                    ],
                    "id": "#main/bwa-mem"
                },
                {
                    "run": "#pilon.cwl",
                    "in": [
                        {
                            "source": "#main/samtools-sort/sorted_bam",
                            "id": "#main/pilon/aligned_bam"
                        },
                        {
                            "source": "#main/samtools-index/bam_index",
                            "id": "#main/pilon/bam_index"
                        },
                        {
                            "source": "#main/INPUT_FASTA",
                            "id": "#main/pilon/genome_fasta"
                        },
                        {
                            "source": "#main/THREADS",
                            "id": "#main/pilon/threads"
                        }
                    ],
                    "out": [
                        "#main/pilon/fasta"
                    ],
                    "id": "#main/pilon"
                },
                {
                    "run": "#samtools-index.cwl",
                    "in": [
                        {
                            "source": "#main/samtools-sort/sorted_bam",
                            "id": "#main/samtools-index/input_bamfile"
                        }
                    ],
                    "out": [
                        "#main/samtools-index/bam_index"
                    ],
                    "id": "#main/samtools-index"
                },
                {
                    "run": "#samtools-sort.cwl",
                    "in": [
                        {
                            "source": "#main/samtools-view/bam",
                            "id": "#main/samtools-sort/input_bamfile"
                        },
                        {
                            "source": "#main/THREADS",
                            "id": "#main/samtools-sort/threads"
                        }
                    ],
                    "out": [
                        "#main/samtools-sort/sorted_bam"
                    ],
                    "id": "#main/samtools-sort"
                },
                {
                    "run": "#samtools-view.cwl",
                    "in": [
                        {
                            "source": "#main/bwa-mem/output",
                            "id": "#main/samtools-view/input_file"
                        },
                        {
                            "source": "#main/THREADS",
                            "id": "#main/samtools-view/threads"
                        }
                    ],
                    "out": [
                        "#main/samtools-view/bam"
                    ],
                    "id": "#main/samtools-view"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#main/pilon/fasta",
                    "id": "#main/fasta"
                }
            ],
            "id": "#main"
        },
        {
            "class": "CommandLineTool",
            "doc": "Pilon for hybrid genome assembly",
            "requirements": [
                {
                    "dockerPull": "quay.io/biocontainers/pilon:1.23--0",
                    "class": "DockerRequirement"
                },
                {
                    "listing": [
                        {
                            "entry": "$(inputs.aligned_bam)",
                            "entryname": "$(inputs.aligned_bam.basename)"
                        },
                        {
                            "entry": "$(inputs.bam_index)",
                            "entryname": "$(inputs.bam_index.basename)"
                        }
                    ],
                    "class": "InitialWorkDirRequirement"
                }
            ],
            "baseCommand": [
                "java"
            ],
            "arguments": [
                {
                    "position": -2,
                    "valueFrom": "-jar"
                },
                {
                    "position": -1,
                    "valueFrom": "/usr/local/share/pilon-1.23-0/pilon-1.23.jar"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "label": "A bam file of unknown type",
                    "doc": "A bam file of unknown type; Pilon will scan it and attempt to classify it",
                    "inputBinding": {
                        "prefix": "--bam"
                    },
                    "id": "#pilon.cwl/aligned_bam"
                },
                {
                    "type": "File",
                    "label": "A bam file index",
                    "id": "#pilon.cwl/bam_index"
                },
                {
                    "type": "File",
                    "label": "genome fasta file to be polished",
                    "inputBinding": {
                        "prefix": "--genome"
                    },
                    "id": "#pilon.cwl/genome_fasta"
                },
                {
                    "type": "string",
                    "default": "14g",
                    "label": "maximum memory size allocated for JVM",
                    "inputBinding": {
                        "prefix": "-Xms",
                        "separate": false,
                        "position": -3
                    },
                    "id": "#pilon.cwl/java_heapsize"
                },
                {
                    "type": "string",
                    "label": "Prefix for output files",
                    "default": "worm.pilon",
                    "inputBinding": {
                        "prefix": "--output"
                    },
                    "id": "#pilon.cwl/output_prefix"
                },
                {
                    "type": "int",
                    "label": "Degree of parallelism to use for certain processing",
                    "default": 4,
                    "doc": "Degree of parallelism to use for certain processing (default 1). Experimental.",
                    "inputBinding": {
                        "prefix": "--threads"
                    },
                    "id": "#pilon.cwl/threads"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output_prefix).fasta"
                    },
                    "id": "#pilon.cwl/fasta"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "*bam"
                    },
                    "id": "#pilon.cwl/out_bam"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "*bai"
                    },
                    "id": "#pilon.cwl/out_bam_index"
                },
                {
                    "type": "File",
                    "id": "#pilon.cwl/stderr",
                    "outputBinding": {
                        "glob": "pilon-stderr.log"
                    }
                },
                {
                    "type": "File",
                    "id": "#pilon.cwl/stdout",
                    "outputBinding": {
                        "glob": "pilon-stdout.log"
                    }
                }
            ],
            "stdout": "pilon-stdout.log",
            "stderr": "pilon-stderr.log",
            "id": "#pilon.cwl"
        },
        {
            "class": "CommandLineTool",
            "doc": "samtools index to create index for given bam file",
            "requirements": [
                {
                    "dockerPull": "quay.io/biocontainers/samtools:1.9--h8571acd_11",
                    "class": "DockerRequirement"
                },
                {
                    "listing": [
                        "$(inputs.input_bamfile)"
                    ],
                    "class": "InitialWorkDirRequirement"
                }
            ],
            "baseCommand": [
                "samtools",
                "index"
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#samtools-index.cwl/input_bamfile"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.input_bamfile.basename).bai"
                    },
                    "id": "#samtools-index.cwl/bam_index"
                },
                {
                    "type": "File",
                    "id": "#samtools-index.cwl/stderr",
                    "outputBinding": {
                        "glob": "samtools-index-stderr.log"
                    }
                },
                {
                    "type": "File",
                    "id": "#samtools-index.cwl/stdout",
                    "outputBinding": {
                        "glob": "samtools-index-stdout.log"
                    }
                }
            ],
            "stdout": "samtools-index-stdout.log",
            "stderr": "samtools-index-stderr.log",
            "id": "#samtools-index.cwl"
        },
        {
            "class": "CommandLineTool",
            "doc": "samtools sort, sort given bam file",
            "requirements": [
                {
                    "dockerPull": "quay.io/biocontainers/samtools:1.9--h8571acd_11",
                    "class": "DockerRequirement"
                }
            ],
            "baseCommand": [
                "samtools",
                "sort"
            ],
            "inputs": [
                {
                    "type": "File",
                    "label": "Input bamfile",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#samtools-sort.cwl/input_bamfile"
                },
                {
                    "type": "string",
                    "default": "aln.sorted.bam",
                    "label": "Write final output to FILENAME",
                    "inputBinding": {
                        "prefix": "-o"
                    },
                    "id": "#samtools-sort.cwl/output_bam"
                },
                {
                    "type": "int",
                    "default": 4,
                    "inputBinding": {
                        "prefix": "-@"
                    },
                    "id": "#samtools-sort.cwl/threads"
                },
                {
                    "type": "string",
                    "default": "sort.tmp",
                    "label": "Write temporary files to PREFIX.nnnn.bam",
                    "inputBinding": {
                        "prefix": "-T"
                    },
                    "id": "#samtools-sort.cwl/tmpfile"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output_bam)"
                    },
                    "id": "#samtools-sort.cwl/sorted_bam"
                },
                {
                    "type": "File",
                    "id": "#samtools-sort.cwl/stderr",
                    "outputBinding": {
                        "glob": "samtools-sort-stderr.log"
                    }
                },
                {
                    "type": "File",
                    "id": "#samtools-sort.cwl/stdout",
                    "outputBinding": {
                        "glob": "samtools-sort-stdout.log"
                    }
                }
            ],
            "stdout": "samtools-sort-stdout.log",
            "stderr": "samtools-sort-stderr.log",
            "id": "#samtools-sort.cwl"
        },
        {
            "class": "CommandLineTool",
            "doc": "samtools view to convert sam format to bam format",
            "requirements": [
                {
                    "dockerPull": "quay.io/biocontainers/samtools:1.9--h8571acd_11",
                    "class": "DockerRequirement"
                }
            ],
            "baseCommand": [
                "samtools",
                "view"
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "label": "Do not output alignments with any bits set in INT present in the FLAG field. INT can be specified in hex by beginning with `0x' (i.e. /^0x[0-9A-F]+/) or in octal by beginning with `0' (i.e. /^0[0-7]+/) [0].",
                    "inputBinding": {
                        "prefix": "-F"
                    },
                    "id": "#samtools-view.cwl/filter_alignments"
                },
                {
                    "type": "boolean",
                    "label": "ignored for compatibility with previous samtools versions",
                    "default": false,
                    "inputBinding": {
                        "prefix": "-S"
                    },
                    "id": "#samtools-view.cwl/ignore_previous_version"
                },
                {
                    "type": "boolean",
                    "label": "include the header in the output",
                    "default": false,
                    "inputBinding": {
                        "prefix": "-h"
                    },
                    "id": "#samtools-view.cwl/include_header"
                },
                {
                    "type": "File",
                    "label": "input file",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#samtools-view.cwl/input_file"
                },
                {
                    "type": "boolean",
                    "label": "output BAM",
                    "default": true,
                    "inputBinding": {
                        "prefix": "-b"
                    },
                    "id": "#samtools-view.cwl/output_bam"
                },
                {
                    "type": "string",
                    "label": "output file name",
                    "default": "aln.bam",
                    "inputBinding": {
                        "prefix": "-o"
                    },
                    "id": "#samtools-view.cwl/output_filename"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "label": "Skip alignments with MAPQ smaller than INT [0].",
                    "inputBinding": {
                        "prefix": "-q"
                    },
                    "id": "#samtools-view.cwl/skip_alignments"
                },
                {
                    "type": "int",
                    "label": "Number of additional threads to use",
                    "default": 4,
                    "inputBinding": {
                        "prefix": "-@"
                    },
                    "id": "#samtools-view.cwl/threads"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output_filename)"
                    },
                    "id": "#samtools-view.cwl/bam"
                },
                {
                    "type": "File",
                    "id": "#samtools-view.cwl/stderr",
                    "outputBinding": {
                        "glob": "samtools-view-stderr.log"
                    }
                },
                {
                    "type": "File",
                    "id": "#samtools-view.cwl/stdout",
                    "outputBinding": {
                        "glob": "samtools-view-stdout.log"
                    }
                }
            ],
            "stdout": "samtools-view-stdout.log",
            "stderr": "samtools-view-stderr.log",
            "id": "#samtools-view.cwl"
        }
    ],
    "cwlVersion": "v1.0"
}
